'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var tslib = require('tslib');
var React = require('react');
var React__default = _interopDefault(React);
var reactJss = require('react-jss');
var clsx = _interopDefault(require('clsx'));

var useStepperStyles =
/*#__PURE__*/
reactJss.createUseStyles({
  StepperContainer: {
    display: 'flex',
    alignItems: 'flex-start',
    flexDirection: 'row',
    padding: 24,
    fontFamily: 'Arial, Helvetica, sans-serif'
  },
  StepContainer: {
    flex: 1,
    position: 'relative',
    paddingLeft: 8,
    paddingRight: 8
  }
});
var stepStyleDefaults = {
  activeBgColor: '#ed1d24',
  activeTextColor: '#ffffff',
  completedBgColor: '#a10308',
  completedTextColor: '#ffffff',
  inactiveBgColor: '#e0e0e0',
  inactiveTextColor: '#ffffff',
  size: '2em',
  circleFontSize: '1rem',
  labelFontSize: '0.875rem',
  borderRadius: '50%',
  fontWeight: 500
};
var useStepStyles =
/*#__PURE__*/
reactJss.createUseStyles({
  StepMain: {
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center'
  },
  StepCircle: function StepCircle(props) {
    return {
      borderRadius: props.borderRadius,
      backgroundColor: props.inactiveBgColor,
      width: props.size,
      height: props.size,
      fontSize: '1em',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
      '&.active': {
        backgroundColor: props.activeBgColor
      },
      '&.completed': {
        backgroundColor: props.completedBgColor
      }
    };
  },
  StepButton: {
    border: 'none',
    margin: 0,
    padding: 0,
    cursor: 'pointer'
  },
  StepCircleContent: function StepCircleContent(props) {
    return {
      color: props.inactiveTextColor,
      fontSize: props.circleFontSize,
      fontVariantNumeric: 'tabular-nums',
      '&.active': {
        color: props.activeTextColor
      },
      '&.completed': {
        color: props.completedTextColor
      }
    };
  },
  LabelContainer: function LabelContainer(props) {
    return {
      width: '100%',
      fontSize: props.labelFontSize,
      fontWeight: 400,
      lineHeight: 1.4
    };
  },
  Label: function Label(props) {
    return {
      display: 'block',
      marginTop: 16,
      textAlign: 'center',
      fontWeight: props.fontWeight
    };
  }
});
var connectorStyleDefaults = {
  disabledColor: '#bdbdbd',
  activeColor: '#ed1d24',
  completedColor: '#a10308',
  size: 1,
  style: 'solid'
};
var useConnectorStyles =
/*#__PURE__*/
reactJss.createUseStyles({
  ConnectorContainer: function ConnectorContainer(props) {
    return {
      top: "calc((" + props.stepSize + " - " + props.size + ") / 2)",
      left: "calc(-50% + " + props.stepSize + " - 8px)",
      right: "calc(50% + " + props.stepSize + " - 8px)",
      position: 'absolute'
    };
  },
  Connector: function Connector(props) {
    return {
      borderTopStyle: props.style,
      borderTopWidth: props.size,
      borderColor: props.disabledColor,
      display: 'block',
      '&.completed': {
        borderColor: props.completedColor
      },
      '&.active': {
        borderColor: props.activeColor
      }
    };
  }
});

var Step = function Step(_a) {
  var children = _a.children,
      _b = _a.label,
      label = _b === void 0 ? '' : _b,
      styleConfig = _a.styleConfig,
      _c = _a.completed,
      completed = _c === void 0 ? false : _c,
      _d = _a.active,
      active = _d === void 0 ? false : _d,
      className = _a.className,
      rest = tslib.__rest(_a, ["children", "label", "styleConfig", "completed", "active", "className"]);

  var stepStyleProps = tslib.__assign(tslib.__assign({}, styleConfig), {
    completed: completed,
    active: active
  });

  var classes = useStepStyles(tslib.__assign(tslib.__assign(tslib.__assign({}, stepStyleDefaults), {
    circleFontSize: "calc(" + stepStyleProps.size + " / 2)"
  }), stepStyleProps));
  return React.createElement("div", {
    className: classes.StepMain
  }, React.createElement("button", tslib.__assign({
    disabled: !active && !completed,
    className: clsx(classes.StepCircle, classes.StepButton, {
      active: active
    }, {
      completed: completed
    }, className)
  }, rest), React.createElement("span", {
    className: clsx(classes.StepCircleContent, {
      active: active
    }, {
      completed: completed
    })
  }, children)), label && React.createElement("div", {
    className: classes.LabelContainer
  }, React.createElement("span", {
    className: classes.Label
  }, label)));
};

var Connector = function Connector(_a) {
  var _b = _a.completed,
      completed = _b === void 0 ? false : _b,
      _c = _a.active,
      active = _c === void 0 ? false : _c,
      _d = _a.stateColors,
      stateColors = _d === void 0 ? false : _d,
      connectorStyle = _a.connectorStyle;

  var convertNumericToPixel = function convertNumericToPixel(object, property) {
    if (typeof object[property] === 'number') {
      object[property] = object[property] + "px";
    }
  };

  convertNumericToPixel(connectorStyle, 'stepSize');
  convertNumericToPixel(connectorStyle, 'size');
  var classes = useConnectorStyles(connectorStyle);
  return React__default.createElement("div", {
    className: classes.ConnectorContainer
  }, React__default.createElement("span", {
    className: clsx(classes.Connector, {
      completed: completed && stateColors
    }, {
      active: active && stateColors
    })
  }));
};

var generateId = function generateId(rule) {
  return "RFS-" + rule.key;
};

var createGenerateId = function createGenerateId() {
  return generateId;
};

reactJss.jss.setup({
  createGenerateId: createGenerateId
});

var Stepper = function Stepper(_a) {
  var steps = _a.steps,
      children = _a.children,
      _b = _a.connectorStateColors,
      connectorStateColors = _b === void 0 ? false : _b,
      _c = _a.className,
      className = _c === void 0 ? '' : _c,
      _d = _a.stepClassName,
      stepClassName = _d === void 0 ? '' : _d,
      _e = _a.activeStep,
      activeStep = _e === void 0 ? 0 : _e,
      styleConfig = _a.styleConfig,
      connectorStyleConfig = _a.connectorStyleConfig,
      _f = _a.hideConnectors,
      hideConnectors = _f === void 0 ? false : _f;
  var classes = useStepperStyles();

  var generateStepProps = function generateStepProps(index, activeStep) {
    return {
      className: stepClassName,
      children: index + 1,
      completed: index < activeStep,
      active: index === activeStep,
      styleConfig: styleConfig
    };
  };

  var useStepsProp = steps instanceof Array && steps.length > 0;
  var stepsArray = useStepsProp ? steps : React__default.Children.toArray(children);
  var stepsToRender = stepsArray.map(function (step, index) {
    if (!useStepsProp && !React__default.isValidElement(step)) return null;
    var stepProps = generateStepProps(index, activeStep);
    return React__default.createElement("div", {
      key: index,
      className: classes.StepContainer
    }, index !== 0 && ( // If hideConnectors === 'inactive' render only active or completed connectors
    // If hideConnectors is something other than 'inactive' or true render all connectors
    hideConnectors === 'inactive' && (stepProps.active || stepProps.completed) || hideConnectors !== true && hideConnectors !== 'inactive') && React__default.createElement(Connector, {
      completed: stepProps.completed,
      active: stepProps.active,
      stateColors: connectorStateColors,
      connectorStyle: tslib.__assign(tslib.__assign(tslib.__assign({}, connectorStyleDefaults), connectorStyleConfig), {
        stepSize: styleConfig && styleConfig.size || stepStyleDefaults.size
      })
    }), React__default.isValidElement(step) ? React__default.cloneElement(step, tslib.__assign(tslib.__assign({}, stepProps), step.props)) : React__default.createElement(Step, tslib.__assign({}, stepProps, step)));
  });
  return React__default.createElement("div", {
    className: clsx(classes.StepperContainer, className)
  }, stepsToRender);
};

exports.Step = Step;
exports.Stepper = Stepper;
//# sourceMappingURL=react-form-stepper.cjs.development.js.map
